Documentation
¶
Index ¶
- Variables
- func Add(usr global.Stu) (string, error)
- func DelPwdResetDetails(rollno int) error
- func DelRdmDetails(redeemer int) error
- func DelTfrDetails(sender int) error
- func GetBatchnRole(rollno int) (string, string, error)
- func GetCntEvents(rollno int) (int, error)
- func GetCoins(rollno interface{}) (float64, error)
- func GetJWTid(rollno int) (string, error)
- func GetPwdResetDetails(rollno int) (global.PwdResetObj, string, error)
- func GetRdmDetails(redeemer int) (global.RedeemObj, string, error)
- func GetTfrDetails(sender int) (global.TxnObj, string, error)
- func GetUsrDetails(rollno int) (struct{ ... }, error)
- func RedeemReq(rdm global.RedeemObj) (interface{}, error)
- func Reward(Tx global.TxnObj) (interface{}, error)
- func SetJWTid(rollno int, jti string) error
- func SetPwdResetDetails(resetPwd global.PwdResetObj) error
- func SetRdmDetails(rdm global.RedeemObj) error
- func SetTfrDetails(tfr global.TxnObj) error
- func ShowAllRdmReqs() (interface{}, error)
- func ShowRdmSts(redeemer int) (interface{}, error)
- func Transact(Tx global.TxnObj) (interface{}, error)
- func UpdPwd(rollno int, pwd string) error
- func UpdRdmSts(redeemReq global.RedeemStatusUPDBody) (interface{}, error)
Constants ¶
This section is empty.
Variables ¶
var InitErr error
var InitMsg string
Functions ¶
func DelPwdResetDetails ¶
func DelRdmDetails ¶
func DelTfrDetails ¶
func GetBatchnRole ¶
Get the batch and role for the given rollno (if present)
func GetCntEvents ¶
Get the count of the number of events in which the given rollno (if present) has participated in
func GetPwdResetDetails ¶
func GetPwdResetDetails(rollno int) (global.PwdResetObj, string, error)
func GetUsrDetails ¶
Get the user details (password, batch, and role) for the given rollno (if present)
func SetPwdResetDetails ¶
func SetPwdResetDetails(resetPwd global.PwdResetObj) error
func SetRdmDetails ¶
func SetTfrDetails ¶
func ShowAllRdmReqs ¶
func ShowAllRdmReqs() (interface{}, error)
Show all pending redeem requests (to the admin) [A list of objects of type global.RedeemReqObj is returned]
func ShowRdmSts ¶
Show the statuses of all redeem requests to a user [A list of objects of type global.UserRedeemState is returned]
func UpdRdmSts ¶
func UpdRdmSts(redeemReq global.RedeemStatusUPDBody) (interface{}, error)
Update redeem status
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.